# Agenten Plattform
#
# (c) 2024 Magnus Bender
# 	Institute of Humanities-Centered Artificial Intelligence (CHAI)
# 	Universitaet Hamburg
# 	https://www.chai.uni-hamburg.de/~bender
#  
# source code released under the terms of GNU Public License Version 3
# https://www.gnu.org/licenses/gpl-3.0.txt

from ums.agent import ExtractAudioAgent, ExtractImageAgent

from ums.utils.types import RiddleData

"""
	Examples for simple agents.

	Each agent is represented by its own class. The handling of tasks is done by `handle()` in each agent.

	Finally `AGENT_CLASSES` contains the classes of the agents in a list. Via environmental variables this list is specified to the ums.agent system. 
"""

class MyExtractAudioAgent(ExtractAudioAgent):

	def handle(self, data: RiddleData) -> RiddleData:
		print("Audio Process:", data.file_plain)
		return data

class MyExtractImageAgent(ExtractImageAgent):

	def handle(self, data: RiddleData) -> RiddleData:
		print("Image Process:", data.file_plain)
		return data

AGENT_CLASSES = [
	MyExtractAudioAgent, MyExtractImageAgent
]